"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.describe = exports.command = void 0;

var _postcss = require("../utils/postcss");

var _hexToTokens = _interopRequireDefault(require("../plugins/hex-to-tokens"));

var _fs = require("fs");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const command = "hex-to-tokens <files...>";
exports.command = command;
const describe = "Replaces hex colors with their closest matched mapped tokens";
exports.describe = describe;

const builder = yargs => {
  yargs.options({
    c: {
      alias: "config",
      describe: "hex to token mapping file location",
      type: "string",
      required: true
    },
    t: {
      alias: "threshold",
      describe: "the delta-e threshold",
      type: "number",
      default: 0
    }
  }).check(argv => {
    if (argv.threshold < 0 || argv.threshold > 100) {
      throw new Error("Threshold must be within the range [0, 100]");
    }

    return true;
  });
};

exports.builder = builder;

const handler = argv => {
  const config = JSON.parse((0, _fs.readFileSync)(argv.config, "utf8"));
  return (0, _postcss.processFiles)(argv.files, (0, _postcss.createProcessor)([(0, _hexToTokens.default)({
    config: config,
    threshold: argv.threshold
  })]));
};

exports.handler = handler;