"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.processFiles = exports.createProcessor = void 0;

var _fs = require("fs");

var _npmlog = _interopRequireDefault(require("npmlog"));

var _postcss = _interopRequireDefault(require("postcss"));

var _postcssScss = _interopRequireDefault(require("postcss-scss"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const createProcessor = function createProcessor(plugins) {
  const configured = (0, _postcss.default)(plugins);
  return css => {
    return configured.process(css, {
      parser: _postcssScss.default,
      from: "CSS"
    });
  };
};

exports.createProcessor = createProcessor;

const processFiles = function processFiles(files, process) {
  return Promise.all(files.map(file => {
    const css = (0, _fs.readFileSync)(file, "utf8");
    return process(css).then(result => {
      (0, _fs.writeFileSync)(file, result.css);

      _npmlog.default.info(file);
    });
  })).catch(error => {
    _npmlog.default.error(error);
  });
};

exports.processFiles = processFiles;